
package Mail::SpamAssassin::CompiledRegexps::body_neg2000;

use strict;

use XSLoader ();

BEGIN {
our $VERSION = '1.0';
our @ISA = qw(XSLoader);
our @EXPORT_OK = qw();

our $HAS_RULES = {
  
};

XSLoader::load 'Mail::SpamAssassin::CompiledRegexps::body_neg2000', $VERSION;
}

1;
__END__

=head1 NAME

Mail::SpamAssassin::CompiledRegexps::body_neg2000 - Efficient string matching for regexps found in bases_body_neg2000.in

=head1 SYNOPSIS

  use Mail::SpamAssassin::CompiledRegexps::body_neg2000;
  
  ...
  my $match = Mail::SpamAssassin::CompiledRegexps::body_neg2000::scan($string);

=head1 DESCRIPTION

This module was created by SpamAssassin with the aid of re2xs, which uses re2c
to create an XS library capable of scanning through a bunch of regular
expressions as defined in F<bases_body_neg2000.in>.

See C<sa-compile> for more details.

=cut
